@@ -3,7 +3,7 @@ import platform
 import sys
 from datetime import datetime
 from rich import print
-from rich.tree import Tree
+from rich.console import Console
 from rich.panel import Panel
 from rich.columns import Columns
 from rich.text import Text
@@ -39,6 +39,30 @@ def print_command_header(command: str):
     )
 
 
+def print_ssh_key_warning_message():
+    """Warning message for user regarding ssh key"""
+    have_ssh = None
+    console = Console()
+    prompt = "⚠️ [bright_white]Do you have an ssh key setup[/bright_white] [dim italic](y, n)[/dim italic] "
+
+    while have_ssh not in ["y", "n"]:
+        have_ssh = console.input(prompt)
+        del_last_line()
+
+    print(f"{prompt}[cyan]{have_ssh}[/cyan]")
+
+    have_ssh = True if have_ssh == "y" else False
+
+    # Exit execution if no setup
+    if not have_ssh:
+        print()
+        print("Please setup an ssh key before using the `create-app` command.")
+        help_link = "[italic bold cyan][link=https://docs.gitlab.com/ee/ssh/#generate-an-ssh-key-pair]generate ssh key[/link][/italic bold cyan]"
+        print(f"> Refer to {help_link} to correctly setup one.")
+        print()
+        exit()
+
+
 def clr_scr():
     """Clear screen on all os"""
     if platform.system().lower() == "windows":
