@@ -1,26 +1,21 @@
 import requests
 import json
 import pathlib
+import yaml
 from urllib.parse import urlencode
 from typing import List, Union
 from requests.models import Response
 from rich import print
 from rich.console import Console
+from yaml.loader import SafeLoader
 from ._typing import Group, Project
 from .errors import APIError
 
 
-BASE_URI = "https://gitedu.hesge.ch/api/v4"
+token: str
+base_uri: str
 console = Console()
 
-try:
-    token = open(
-        pathlib.Path(__file__).resolve().parent.absolute() / "config.txt", "r"
-    ).read()
-except Exception as e:
-    token = ""
-
-
 # =============
 # Decorator
 # =============
@@ -32,12 +27,40 @@ def need_api_token(func):
     """
 
     def wrapper_func(*args, **kwargs):
-        if token == "":
+        global token, base_uri
+
+        # =============
+        # Retrieve config
+        # =============
+        try:
+            with open(
+                pathlib.Path(__file__).resolve().parent.absolute() / "config.yaml", "r"
+            ) as f:
+                config = dict(yaml.load(f, Loader=SafeLoader))
+
+                if not config["token"]:
+                    raise Exception("No token found")
+
+                token = config["token"]
+                base_uri = config["target"]  # Always have a default value
+        except (FileNotFoundError, Exception) as e:
+            if isinstance(e, FileNotFoundError):
+                print(
+                    "Before making any calls, you need to setup at least your token by doing : hpm setup --token <TOKEN_VALUE>"
+                )
+                print(
+                    "You can also setup a custom target uri by adding the parameter `--target <TARGET_URI>`"
+                )
+                exit()
+
+            token = None
+
+        if not token:
             print(
-                "No token as been register. Please do so using `setup --token <TOKEN_VALUE>.`"
+                "No token as been register. Please do so using `hpm setup --token <TOKEN_VALUE>.`"
             )
             exit()  # Force program exit because nothing will run correctly if no token as been provided
-        func(*args, **kwargs)
+        return func(*args, **kwargs)
 
     return wrapper_func
 
@@ -80,13 +103,13 @@ def _create_project_from_json(json_response: dict) -> Project:
         json_response["description"],
         json_response["web_url"],
         json_response["name"],
+        json_response["path"],
         json_response["path_with_namespace"],
         json_response["star_count"],
         json_response["open_issues_count"],
         json_response["namespace"]["id"],
         json_response["namespace"]["name"],
         json_response["ssh_url_to_repo"],
-        json_response["http_url_to_repo"],
     )
 
 
@@ -123,7 +146,7 @@ def get_owned_groups() -> List[Group]:
     Returns:
         Group[]: List of owned groups
     """
-    url = f"{BASE_URI}/groups?owned=true&per_page=100"
+    url = f"{base_uri}/groups?owned=true&per_page=100"
 
     payload = {}
     headers = {"Private-Token": token}
@@ -154,7 +177,7 @@ def get_owned_projects(page=1):
     Return:
         Project[]: List of owned projects
     """
-    url = f"{BASE_URI}/projects?membership=true&page={page}"
+    url = f"{base_uri}/projects?membership=true&page={page}"
 
     payload = {}
     headers = {"Private-Token": token}
@@ -194,11 +217,14 @@ def create_project(params: list) -> Union[Project, APIError]:
     Returns:
         Project: Newly created project
     """
-    url = f"{BASE_URI}/projects?"
+    url = f"{base_uri}/projects?"
 
     # Build url parameters
     url_params = {}
     for param in params:
+        if param["non_api"]:
+            continue
+        
         if param["value"] is not None and param["value"] != "":
             url_params[param["key"]] = param["value"]
 
@@ -232,7 +258,7 @@ def get_subgroups(parent: Group) -> List[Group]:
     Returns:
         List[Group]: List of subgroups
     """
-    url = f"{BASE_URI}/groups/{parent.id}/subgroups"
+    url = f"{base_uri}/groups/{parent.id}/subgroups"
 
     payload = {}
     headers = {"Private-Token": token}
@@ -262,7 +288,7 @@ def get_group_projects(group: Group) -> List[Project]:
     Returns:
         List[Project]: List of projects
     """
-    url = f"{BASE_URI}/groups/{group.id}/projects"
+    url = f"{base_uri}/groups/{group.id}/projects"
 
     payload = {}
     headers = {"Private-Token": token}
@@ -292,7 +318,7 @@ def get_group(group_id: int) -> Group:
     Returns:
         Group: Found group
     """
-    url = f"{BASE_URI}/groups/{group_id}"
+    url = f"{base_uri}/groups/{group_id}"
 
     payload = {}
     headers = {"Private-Token": token}
@@ -303,6 +329,6 @@ def get_group(group_id: int) -> Group:
     if not _validate_api_response(response):
         return None
 
-    response = json.loads(response)
+    response = json.loads(response.text)
 
     return _create_group_from_json(response)
